@@ -5,7 +5,7 @@ Created on Fri Aug  5 15:42:27 2022
 
 @author: smn06
 """
-from visualize import *
+from final_test05.visualize import *
 
 def adaboost(X_train, X_test, y_train, y_test):
     #importing and fitting the model from sklearn
